# Common functionality

The functioality provided in this repository is used by libraries developed at the Gatsby Computational Neuroscience Unit (e.g., [Sparse Variational Gaussian Process Factor Analysis](https://github.com/joacorapela/svGPFA)).
